@@ -8,7 +8,7 @@ use version ();
 use Compiler::Lexer 0.07;
 use List::Util qw(max);
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 my $MIN_VERSION   = version->new('5.008');
 my $VERSION_5_018 = version->new('5.018');
@@ -161,6 +161,21 @@ sub _build_minimum_syntax_version {
             } else {
                 $test->("normal when" => $VERSION_5_010);
             }
+        } elsif ($token->{name} eq 'BuiltinFunc') {
+            if ($token->data eq 'each' || $token->data eq 'keys' || $token->data eq 'values') {
+                my $func = $token->data;
+                if (@tokens >= $i+1) {
+                    my $next_token = $tokens[$i+1];
+                    warn $next_token->name;
+                    if ($next_token->name eq 'GlobalVar' || $next_token->name eq 'Var') {
+                        # each $hashref
+                        # each $arrayref
+                        $test->("$func \$hashref, $func \$arrayref" => $VERSION_5_014);
+                    } elsif ($next_token->name eq 'GlobalArrayVar' || $next_token->name eq 'ArrayVar') {
+                        $test->("$func \@array" => $VERSION_5_012);
+                    }
+                }
+            }
         }
     }
     return $syntax_version;
